pub struct DefaultsDerivesConfig {
pub return_type: Vec<String>,
pub parameters_type: Vec<String>,
pub conditions_type: Vec<String>,
pub error_type: Vec<String>,
}Expand description
Default derive traits configuration for all generated types
Fields
return_type: Vec<String>Derive traits for return type structs Defaults to empty vec (Debug is always added)
parameters_type: Vec<String>Derive traits for parameters structs Defaults to empty vec (Debug is always added)
conditions_type: Vec<String>Derive traits for conditions structs Defaults to empty vec (Debug is always added)
error_type: Vec<String>Derive traits for error constraint enums Defaults to empty vec (Debug is always added)